@@ -15,6 +15,7 @@
 
 """Common shared functions."""
 
+from importlib import metadata
 import argparse
 import logging
 import platform
@@ -24,7 +25,7 @@ import langdetect
 
 logger = logging.getLogger(__name__)
 
-__version__ = "0.1.126"
+__version__ = metadata.version("txt2ebook")
 
 
 def setup_logger(config: argparse.Namespace) -> None:
