@@ -23,7 +23,7 @@ issues: https://github.com/kianmeng/txt2ebook/issues
 import argparse
 import logging
 import sys
-from typing import Optional, Sequence
+from typing import Sequence
 
 import txt2ebook.subcommands
 from txt2ebook import __version__, setup_logger
@@ -71,6 +71,15 @@ def build_parser() -> argparse.ArgumentParser:
         ),
     )
 
+    parser.add_argument(
+        "-y",
+        "--yes",
+        default=False,
+        action="store_true",
+        dest="yes",
+        help="assume yes to all prompts (default: '%(default)s')",
+    )
+
     parser.add_argument(
         "-l",
         "--language",
@@ -134,7 +143,7 @@ def build_parser() -> argparse.ArgumentParser:
     return parser
 
 
-def main(args: Optional[Sequence[str]] = None):
+def main(args: Sequence[str] | None = None):
     """Set the main entrypoint of the CLI script."""
     args = args or sys.argv[1:]
 
