@@ -16,5 +16,9 @@
 """List of all exceptions used for this application."""
 
 
+class InputError(Exception):
+    """Raised when the input arguments are invalid."""
+
+
 class EmptyFileError(Exception):
     """Raised when the input file has no content."""
