@@ -19,7 +19,7 @@ import logging
 import uuid
 from importlib.resources import contents, read_text
 from pathlib import Path
-from typing import Optional
+
 
 from ebooklib import epub
 
@@ -181,7 +181,7 @@ class EpubWriter(BaseWriter):
         return epub_html
 
     def _build_chapter(
-        self, chapter: Chapter, volume: Optional[Volume] = None
+        self, chapter: Chapter, volume: Volume | None = None
     ) -> epub.EpubHtml:
         """Generate the whole chapter to HTML."""
         if volume:
