@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -147,7 +147,7 @@ class PdfWriter(BaseWriter):
             style.borderColor = "#000000"
 
         footer = Paragraph(f"{doc.page}", style=style)
-        _width, _height = footer.wrap(doc.width, doc.bottomMargin)
+        footer.wrap(doc.width, doc.bottomMargin)
         footer.drawOn(canvas, doc.leftMargin, doc.bottomMargin - cm)
 
         canvas.restoreState()
