@@ -22,7 +22,8 @@ logger = logging.getLogger(__name__)
 
 
 def lower_underscore(string: str) -> str:
-    """Convert a string to lower case and replace multiple spaces to single underscore.
+    """Convert a string to lower case and replace multiple spaces to single
+    underscore.
 
     Args:
         string (str): A string.
