@@ -18,7 +18,7 @@
 import logging
 from collections import Counter
 from dataclasses import dataclass, field
-from typing import List, Union
+from typing import List
 
 from txt2ebook.models.chapter import Chapter
 from txt2ebook.models.volume import Volume
@@ -38,7 +38,7 @@ class Book:
     language: str = field(default="")
     cover: str = field(default="", repr=False)
     raw_content: str = field(default="", repr=False)
-    toc: List[Union[Volume, Chapter]] = field(default_factory=list, repr=False)
+    toc: List[Volume | Chapter] = field(default_factory=list, repr=False)
 
     def stats(self) -> Counter:
         """Returns the statistics count for the parsed tokens.
