@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -35,18 +35,19 @@ def build_subparser(subparsers) -> None:
 
 
 def run(_args: argparse.Namespace) -> None:
-    """Run env subcommand.
+    """Run the env subcommand to print environment information.
 
     Args:
-        config (argparse.Namespace): Config from command line arguments
+        _args (argparse.Namespace): Config from command line arguments
+        (unused).
 
     Returns:
         None
     """
     sys_version = sys.version.replace("\n", "")
-    print(
+    env = [
         f"txt2ebook: {__version__}",
         f"python: {sys_version}",
         f"platform: {platform.platform()}",
-        sep="\n",
-    )
+    ]
+    print(*env, sep="\n")
