@@ -28,8 +28,11 @@ from bs4 import UnicodeDammit
 
 from txt2ebook import detect_and_expect_language
 from txt2ebook.exceptions import EmptyFileError
+from txt2ebook.formats.txt import TxtWriter
 from txt2ebook.models.book import Book
-from txt2ebook.zh_utils import zh_halfwidth_to_fullwidth, zh_words_to_numbers
+from txt2ebook.parser import Parser
+from txt2ebook.languages.zh_base import zh_halfwidth_to_fullwidth, zh_words_to_numbers
+from txt2ebook.cli import DEFAULT_OUTPUT_FOLDER
 
 logger = logging.getLogger(__name__)
 
@@ -57,6 +60,14 @@ def build_subparser(subparsers) -> None:
         metavar="EBOOK_FILENAME",
     )
 
+    massage_parser.add_argument(
+        "-of",
+        "--output-folder",
+        dest="output_folder",
+        default=DEFAULT_OUTPUT_FOLDER,
+        help="set default output folder (default: '%(default)s')",
+    )
+
     massage_parser.add_argument(
         "-hn",
         "--header-number",
@@ -210,33 +221,34 @@ def run(args: argparse.Namespace) -> None:
     """Run massage subcommand.
 
     Args:
-        args (argparse.Namespace): args.from command line arguments
+        args (argparse.Namespace): arguments from command line arguments
 
     Returns:
         None
     """
     massaged_txt = massage_txt(args)
-    if args.overwrite:
+
+    if args.split_volume_and_chapter:
+        args.language = detect_and_expect_language(massaged_txt, args.language)
+        config_lang = args.language.replace("-", "_")
+        langconf = import_module(f"txt2ebook.languages.{config_lang}")
+        args.with_toc = False
+        parser = Parser(massaged_txt, args, langconf)
+        book = parser.parse()
+
+        if args.debug:
+            book.debug(args.verbose)
+
+        if args.header_number:
+            book = header_number(args, book)
+
+        writer = TxtWriter(book, args, langconf)
+        writer.write()
+    elif args.overwrite:
         _overwrite_file(args, massaged_txt)
     else:
         _new_file(args, massaged_txt)
 
-    # args.language = detect_and_expect_language(massaged_txt, args.language)
-    # config_lang = args.language.replace("-", "_")
-    # langconf = import_module(f"txt2ebook.languages.{config_lang}")
-    # args.with_toc = False
-    # parser = Parser(massaged_txt, args, langconf)
-    # book = parser.parse()
-
-    # if args.debug:
-    #     book.debug(args.verbose)
-
-    # if args.header_number:
-    #     book = header_number(args, book)
-
-    # writer = TxtWriter(book, args)
-    # writer.write()
-
 
 def _overwrite_file(args, massaged_txt) -> None:
     txt_filename = Path(args.input_file.name)
@@ -265,8 +277,8 @@ def header_number(args: argparse.Namespace, book: Book) -> Book:
     stats = book.stats()
 
     seq_lengths = {
-        "Volume": len(str(stats.get("Volume", 2))),
-        "Chapter": len(str(stats.get("Chapter", 2))),
+        "Volume": max(2, len(str(stats.get("Volume", 2)))),
+        "Chapter": max(2, len(str(stats.get("Chapter", 2)))),
     }
 
     for toc_item in book.toc:
@@ -316,8 +328,8 @@ def words_to_nums(args: argparse.Namespace, words: str, length: int) -> str:
 
     logger.debug(
         "Convert header to numbers: %s -> %s",
-        words[:10],
-        replaced_words[:10],
+        words,
+        replaced_words,
     )
     return replaced_words
 
@@ -356,11 +368,13 @@ def massage_txt(args: argparse.Namespace) -> str:
     if args.re_delete_line:
         body = do_delete_line_regex(args, body)
 
-    if args.single_newline:
-        body = do_single_newline(args, body)
-
     if args.width:
         body = do_wrapping(args, body)
+    elif args.single_newline:
+        body = do_single_newline(args, body)
+    else:
+        # Apply paragraph separation and line unwrapping by default
+        body = _unwrap_content(args, body)
 
     return f"{metadata}{body}"
 
@@ -376,6 +390,7 @@ def to_unix_newline(content: str) -> str:
     """
     return content.replace("\r\n", "\n").replace("\r", "\n")
 
+
 def do_reindent_paragraph(args, content: str) -> str:
     """Reindent each paragraph.
 
@@ -385,16 +400,16 @@ def do_reindent_paragraph(args, content: str) -> str:
     Returns:
         str: The formatted book content.
     """
-    paragraphs = re.split(r'\n\s*\n+', content)
+    paragraphs = re.split(r"\n\s*\n+", content)
     reindented_paragraphs = []
     for paragraph in paragraphs:
-        lines = paragraph.split('\n')
+        lines = paragraph.split("\n")
         reindented_lines = []
         for line in lines:
             stripped_line = line.strip()
             reindented_lines.append(stripped_line)
 
-        reindented_paragraph = '\n'.join(reindented_lines)
+        reindented_paragraph = "\n".join(reindented_lines)
         reindented_paragraph = "　　" + reindented_paragraph
         reindented_paragraphs.append(reindented_paragraph)
 
@@ -472,7 +487,6 @@ def extract_metadata_and_body(_args, content: str) -> tuple:
         metadata = match.group(0).strip()
         body = content.replace(metadata, "", 1)
 
-
     metadata_block = metadata.split("---")[1]
 
     metadata_dict = {}
@@ -492,33 +506,38 @@ def extract_metadata_and_body(_args, content: str) -> tuple:
     return (meta_str, body)
 
 
-def do_single_newline(args, content: str) -> str:
+def do_single_newline(args: argparse.Namespace, content: str) -> str:
     """Set single newline.
 
     Args:
-        content (str): The formatted book content.
+        args (argparse.Namespace): arguments from command line arguments
+        content (str): The formatted book content
 
     Returns:
         str: The formatted book content.
     """
-    modified_content = re.sub(r"\n+", "\n\n", content)
+    unwrap_content = _unwrap_content(args, content)
+    modified_content = re.sub(r"\n+", "\n\n", unwrap_content)
     return modified_content
 
 
-def do_wrapping(args, content: str) -> str:
+def do_wrapping(args: argparse.Namespace, content: str) -> str:
     """Wrap or fill CJK text.
 
     Args:
-        content (str): The formatted book content.
+        args (argparse.Namespace): arguments from command line arguments
+        content (str): The formatted book content
 
     Returns:
         str: The formatted book content.
     """
     logger.info("Wrapping paragraph to width: %s", args.width)
 
+    unwrap_content = _unwrap_content(args, content)
+
+    # don't remove empty line and keep all formatting as it
     paragraphs = []
-    # We don't remove empty line and keep all formatting as it.
-    for paragraph in content.split("\n"):
+    for paragraph in unwrap_content.split("\n"):
         paragraph = paragraph.strip()
 
         lines = cjkwrap.wrap(paragraph, width=args.width)
@@ -527,3 +546,20 @@ def do_wrapping(args, content: str) -> str:
 
     wrapped_content = "\n".join(paragraphs)
     return wrapped_content
+
+
+def _unwrap_content(args: argparse.Namespace, content: str) -> str:
+    """
+    Args:
+        args (argparse.Namespace): arguments from command line arguments
+        content (str): The formatted book content
+
+    Returns:
+        str: The formatted book content.
+    """
+    paragraphs = re.split(r"\n\s*\n+", content)
+    processed_paragraphs = []
+    for paragraph in paragraphs:
+        single_line_paragraph = " ".join(paragraph.splitlines())
+        processed_paragraphs.append(single_line_paragraph.strip())
+    return args.paragraph_separator.join(processed_paragraphs)
