@@ -19,6 +19,8 @@ import argparse
 import logging
 import sys
 from importlib import import_module
+from types import ModuleType
+from typing import Tuple
 
 import jieba.analyse
 from bs4 import UnicodeDammit
@@ -59,14 +61,15 @@ def build_subparser(subparsers) -> None:
     parse_parser.set_defaults(func=run)
 
 
-def run(args: argparse.Namespace) -> Book:
+def run(args: argparse.Namespace) -> Tuple[Book, ModuleType]:
     """Run env subcommand.
 
     Args:
         args (argparse.Namespace): Config from command line arguments
 
     Returns:
-        None
+        Tuple[Book, ModuleType]: The Book model and the language
+        configuration module.
     """
     logger.info("Parsing txt file: %s", args.input_file.name)
 
@@ -94,4 +97,4 @@ def run(args: argparse.Namespace) -> Book:
     if args.debug:
         book.debug(args.verbose)
 
-    return book
+    return book, langconf
