@@ -20,7 +20,7 @@ import logging
 import re
 from collections import Counter
 from dataclasses import dataclass, field
-from importlib import import_module
+from types import ModuleType
 from typing import Any, Dict, List
 
 from txt2ebook import log_or_raise_on_warning
@@ -55,17 +55,21 @@ class Tokenizer:
     raw_content: str = field(repr=False)
     metadata_marker: str = field(repr=False)
     config: argparse.Namespace = field(repr=False)
+    langconf: ModuleType = field(repr=False)
     tokens: List[Token] = field(default_factory=List, repr=False)
     lineno_lookup: Dict = field(default_factory=Dict, repr=False)
 
-    def __init__(self, raw_content: str, config: argparse.Namespace) -> None:
+    def __init__(
+        self,
+        raw_content: str,
+        config: argparse.Namespace,
+        langconf: ModuleType,
+    ) -> None:
         """Set the constructor for the Tokenizer."""
         self.raw_content = raw_content
         self.config = config
         self.metadata_marker = "---"
-
-        config_lang = config.language.replace("-", "_")
-        self.langconf = import_module(f"txt2ebook.languages.{config_lang}")
+        self.langconf = langconf
 
         lookupcontent = raw_content[:]
         lineno_lookup = {}
@@ -184,7 +188,8 @@ class Tokenizer:
         else:
             # No metadata block found according to the pattern,
             # so assume all raw_content is the actual content.
-            # _extract_metadata would have already logged/warned if metadata was expected.
+            # _extract_metadata would have already logged/warned if metadata
+            # was expected.
             content_str = self.raw_content
 
         content_str = content_str.strip(self.config.paragraph_separator)
